<?php

require_once("scheduler_connector.php");

/*! DataItem class for Scheduler component
**/
class SchedulerJSONDataItem extends DataItem{
	/*! return self as XML string
	*/
	function to_xml(){
		if ($this->skip) return "";
		
		$str="{ \"id\": \"".$this->get_id()."\", ";
		$str.="\"start_date\": \"".$this->data[$this->config->text[0]["name"]]."\", ";
		$str.="\"end_date\": \"".$this->data[$this->config->text[1]["name"]]."\", ";
		$str.="\"text\": \"".$this->escape($this->data[$this->config->text[2]["name"]])."\", ";
		for ($i=3; $i<sizeof($this->config->text); $i++){
			$extra = $this->config->text[$i]["name"];
			$value = $this->escape($this->data[$extra]);
			$str.="\"".$extra."\": \"".$value."\"";
			if ($i < sizeof($this->config->text)-1)
				$str .= ", ";
		}
		return $str."}";
	}
	
	function escape($value) {
		$value = str_replace("\r\n", '\n', $value);
		$value = str_replace("\n", '\n', $value);
		$value = str_replace("\'", "\\\'", $value);
		$value = htmlentities($value);
		
		return $value;
	}
}


class SchedulerJSONConnector extends SchedulerConnector {
	
	/*! assign options collection to the column
		
		@param name 
			name of the column
		@param options
			array or connector object
	*/
	public function set_options($name,$options){
		return "";
	}
	/*! generates xml description for options collections
		
		@param list 
			comma separated list of column names, for which options need to be generated
	*/
	protected function fill_collections(){
		return "";
	}
	
	/*! renders self as  xml, ending part
	*/
	protected function xml_start(){
		return "[";
	}

	/*! renders self as  xml, ending part
	*/
	protected function xml_end(){
		return $this->extra_output."]";
	}
	
	
	/*! constructor
		
		Here initilization of all Masters occurs, execution timer initialized
		@param res 
			db connection resource
		@param type
			string , which hold type of database ( MySQL or Postgre ), optional, instead of short DB name, full name of DataWrapper-based class can be provided
		@param item_type
			name of class, which will be used for item rendering, optional, DataItem will be used by default
		@param data_type
			name of class which will be used for dataprocessor calls handling, optional, DataProcessor class will be used by default. 
	*/	
	public function __construct($res,$type=false,$item_type=false,$data_type=false){
		$this->data_separator = ",";
		if (!$item_type) $item_type="SchedulerJSONDataItem";
		if (!$data_type) $data_type="SchedulerDataProcessor";
		parent::__construct($res,$type,$item_type,$data_type);
	}

	protected function output_as_xml($res){
		$start=$this->xml_start();
		$end=$this->render_set($res).$this->xml_end();
		
		$out = new OutputWriter($start, $end);
		$out->set_type("json");
		$this->event->trigger("beforeOutput", $this, $out);
		$out->output("", true, $this->encoding);
	}


	/*! render from DB resultset
		@param res
			DB resultset 
		process commands, output requested data as XML
	*/
	protected function render_set($res){
		$output=Array();
		$index=0;
		$this->event->trigger("beforeRenderSet",$this,$res,$this->config);
		while ($data=$this->sql->get_next($res)){
			$data = new $this->names["item_class"]($data,$this->config,$index);
			if ($data->get_id()===false)
				$data->set_id($this->uuid());
			$this->event->trigger("beforeRender",$data);
			$output[]=$data->to_xml();
			$index++;
		}
		return implode($this->data_separator, $output);
	}
}
	
?>